.. outset's documentation master file, created by
   sphinx-quickstart on Thu May  5 14:06:45 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Overview
========

.. toctree::
   :maxdepth: 2
   :hidden:

   index
   gallery
   api
   contributing
   package
   indices

.. include:: ../README.rst
